# Logo SPHELP
Write-Output @"
  SSS   PPPP   H   H  EEEEE  L     PPPP   
 S      P   P  H   H  E      L     P   P  
  SSS   PPPP   HHHHH  EEEE   L     PPPP   
     S  P      H   H  E      L     P      
 SSSS   P      H   H  EEEEE  LLLLL  P      
                                         
"@

# Funcao para verificar a fila de disco
function Get-DiskQueueLength {
    $disks = Get-WmiObject Win32_PerfFormattedData_PerfDisk_PhysicalDisk
    $diskInfo = @()

    $diskNames = $disks | Select-Object -ExpandProperty Name

    foreach ($diskName in $diskNames) {
        $queueLength = ($disks | Where-Object { $_.Name -eq $diskName }).CurrentDiskQueueLength
        if ($queueLength -ne $null) {
            $diskInfo += [PSCustomObject]@{
                DeviceID = $diskName
                QueueLength = $queueLength
            }
        }
        else {
            $diskInfo += [PSCustomObject]@{
                DeviceID = $diskName
                QueueLength = 0
            }
        }
    }

    return $diskInfo
}

# Funcao para verificar a latencia do disco
function Get-DiskLatency {
    $disks = Get-WmiObject Win32_PerfFormattedData_PerfDisk_PhysicalDisk
    $diskInfo = @()

    $diskNames = $disks | Select-Object -ExpandProperty Name

    foreach ($diskName in $diskNames) {
        $avgDiskSecPerRead = ($disks | Where-Object { $_.Name -eq $diskName }).AvgDiskSecPerRead
        $avgDiskSecPerWrite = ($disks | Where-Object { $_.Name -eq $diskName }).AvgDiskSecPerWrite
        if ($avgDiskSecPerRead -ne $null -and $avgDiskSecPerWrite -ne $null) {
            $diskInfo += [PSCustomObject]@{
                DeviceID = $diskName
                AvgDiskSecPerRead = $avgDiskSecPerRead * 1000  # Convertendo para milissegundos
                AvgDiskSecPerWrite = $avgDiskSecPerWrite * 1000  # Convertendo para milissegundos
            }
        }
        else {
            $diskInfo += [PSCustomObject]@{
                DeviceID = $diskName
                AvgDiskSecPerRead = 0
                AvgDiskSecPerWrite = 0
            }
        }
    }

    return $diskInfo
}

# Array para armazenar historico de fila
$queueHistory = @()
# Array para armazenar historico de latência
$latencyHistory = @()

# Loop para atualizar a cada 5 segundos
while ($true) {
    Clear-Host  # Limpa a tela para exibir as novas informacoes
 
    # Logo SPHELP
    Write-Output @"
  SSS   PPPP   H   H  EEEEE  L     PPPP   
 S      P   P  H   H  E      L     P   P  
  SSS   PPPP   HHHHH  EEEE   L     PPPP   
     S  P      H   H  E      L     P      
 SSSS   P      H   H  EEEEE  LLLLL  P      
                                         
"@
    Write-Output "Fila de Disco:"
    $queueLength = Get-DiskQueueLength
    $queueLength | Format-Table -AutoSize DeviceID, @{Name="QueueLength (ms)"; Expression={$_.QueueLength * 1000}}
    $queueHistory += @($queueLength)

    Write-Output "`nLatencia do Disco:"
    $diskLatency = Get-DiskLatency
    $diskLatency | Format-Table -AutoSize DeviceID, @{Name="AvgDiskSecPerRead (ms)"; Expression={$_.AvgDiskSecPerRead}}, @{Name="AvgDiskSecPerWrite (ms)"; Expression={$_.AvgDiskSecPerWrite}}
    $latencyHistory += @($diskLatency)

    Start-Sleep -Seconds 5  # Espera 5 segundos antes de atualizar novamente
}
